@@ -116,8 +116,8 @@ g_mozilla_transfer_item_continue (GMozillaTransferItem *self)
     init_progress_timeout (self);
 
     /* if(gtk_mozilla_web_transferitem_continue(GTK_MOZILLAWEBTRANSFERITEM(self->item)) == GTK_MOZILLA_STATUS_OK) { 
-          return G_WEB_STATUS_OK;
-    }*/
+       return G_WEB_STATUS_OK;
+       }*/
     return G_WEB_ERR;
 }
 
@@ -136,7 +136,7 @@ g_mozilla_transfer_item_cancel (GMozillaTransferItem *self)
 
     if (webglobal && G_MOZILLA_WEB (webglobal)->ongoing_download_list)
         G_MOZILLA_WEB (webglobal)->ongoing_download_list = 
-                            g_list_remove (G_MOZILLA_WEB (webglobal)->ongoing_download_list, self);
+            g_list_remove (G_MOZILLA_WEB (webglobal)->ongoing_download_list, self);
 
 }
 
@@ -376,13 +376,13 @@ g_mozilla_transfer_item_new_with_url (const gchar *url,
     if (global_last_gtk_moz_embed_download_object) {
 
         G_MOZILLA_TRANSFER_ITEM(instance)->gtk_moz_embed_download = 
-                                (GtkMozEmbedDownload *) malloc (sizeof (GtkMozEmbedDownload));
+            (GtkMozEmbedDownload *) malloc (sizeof (GtkMozEmbedDownload));
         G_MOZILLA_TRANSFER_ITEM(instance)->gtk_moz_embed_download = global_last_gtk_moz_embed_download_object;
         global_last_gtk_moz_embed_download_object = NULL;
 
     } else  {
         G_MOZILLA_TRANSFER_ITEM(instance)->gtk_moz_embed_download =
-                                      (GtkMozEmbedDownload *) gtk_moz_embed_download_new_with_url_filename (url, filename);
+            (GtkMozEmbedDownload *) gtk_moz_embed_download_new_with_url_filename (url, filename);
     }
 
     if (filename)
@@ -415,8 +415,8 @@ g_mozilla_transfer_item_connect_signals (GMozillaTransferItem *self)
 }
 
 static void 
-start_download_cb (GtkMozEmbedDownload *donwload, gchar **file_name_with_path, GMozillaTransferItem *self) {
-
+start_download_cb (GtkMozEmbedDownload *donwload, gchar **file_name_with_path, GMozillaTransferItem *self)
+{
     TRACE_LOG();
 
     g_signal_emit_by_name(G_OBJECT (self), G_WEB_TRANSFER_ITEM_SIGNAL_STARTED);
@@ -428,8 +428,8 @@ start_download_cb (GtkMozEmbedDownload *donwload, gchar **file_name_with_path, G
 }
 
 static void 
-error_download_cb (GtkMozEmbedDownload *donwload, GMozillaTransferItem *self) {
-
+error_download_cb (GtkMozEmbedDownload *donwload, GMozillaTransferItem *self)
+{
     TRACE_LOG();
     g_signal_emit_by_name(G_OBJECT (self), "error");
 
@@ -437,8 +437,8 @@ error_download_cb (GtkMozEmbedDownload *donwload, GMozillaTransferItem *self) {
 }
 
 static void 
-aborted_download_cb (GtkMozEmbedDownload *donwload, GMozillaTransferItem *self) {
-
+aborted_download_cb (GtkMozEmbedDownload *donwload, GMozillaTransferItem *self)
+{
     TRACE_LOG();
     g_signal_emit_by_name(G_OBJECT (self), "aborted");
 
@@ -446,16 +446,19 @@ aborted_download_cb (GtkMozEmbedDownload *donwload, GMozillaTransferItem *self)
 }
 
 static void 
-completed_download_cb (GtkMozEmbedDownload *donwload, GMozillaTransferItem *self) {
-
+completed_download_cb (GtkMozEmbedDownload *donwload, GMozillaTransferItem *self)
+{
     TRACE_LOG();
     g_signal_emit_by_name(G_OBJECT (self), G_WEB_TRANSFER_ITEM_SIGNAL_COMPLETED);
 
     // reset progress timeout.
     reset_progress_timeout (self);
 
-    if (self->gtk_moz_embed_download)
+    if (self->gtk_moz_embed_download) {
+        if (self->gtk_moz_embed_download == global_last_gtk_moz_embed_download_object)
+            global_last_gtk_moz_embed_download_object = NULL;
         gtk_object_destroy(GTK_OBJECT(self->gtk_moz_embed_download));
+    }
 
     if (webglobal && G_MOZILLA_WEB (webglobal)->ongoing_download_list)
         G_MOZILLA_WEB (webglobal)->ongoing_download_list = g_list_remove (G_MOZILLA_WEB (webglobal)->ongoing_download_list, self);
@@ -465,8 +468,8 @@ completed_download_cb (GtkMozEmbedDownload *donwload, GMozillaTransferItem *self
 }
 
 static void 
-progress_download_cb (GtkMozEmbedDownload *donwload, glong current, glong total, glong mode, GMozillaTransferItem *self) {
-
+progress_download_cb (GtkMozEmbedDownload *donwload, glong current, glong total, glong mode, GMozillaTransferItem *self)
+{
     TRACE_LOG();
 
     init_progress_timeout (self);
@@ -476,7 +479,9 @@ progress_download_cb (GtkMozEmbedDownload *donwload, glong current, glong total,
     return ;
 }
 
-gboolean progress_timeout (GMozillaTransferItem *self) {
+gboolean progress_timeout (GMozillaTransferItem *self)
+{
+    TRACE_LOG();
 
     // reset progress timeout.
     reset_progress_timeout (self);
@@ -486,16 +491,20 @@ gboolean progress_timeout (GMozillaTransferItem *self) {
     return FALSE;
 }
 
-void init_progress_timeout (GMozillaTransferItem *self) {
+void init_progress_timeout (GMozillaTransferItem *self)
+{
+    TRACE_LOG();
 
     // reset progress timeout.
     reset_progress_timeout (self);
 
     self->progress_timer_id = g_timeout_add (PROGRESS_TOLERANCY_INTERVAL, (GSourceFunc)
-                                        progress_timeout, (gpointer) self);
+                                             progress_timeout, (gpointer) self);
 }
 
-void reset_progress_timeout (GMozillaTransferItem *self) {
+void reset_progress_timeout (GMozillaTransferItem *self)
+{
+    TRACE_LOG();
 
     if (self->progress_timer_id) 
     {
@@ -504,7 +513,9 @@ void reset_progress_timeout (GMozillaTransferItem *self) {
     }
 }
 
-void g_mozilla_transfer_item_set_webglobal (GObject *o) {
+void g_mozilla_transfer_item_set_webglobal (GObject *o)
+{
+    TRACE_LOG();
 
     if (!webglobal)
         webglobal = o;
