@@ -115,7 +115,7 @@ g_mozilla_web_destroy (GMozillaWeb *self)
     if(self->default_cursor)
     {
         gdk_cursor_unref(self->default_cursor);
-        self->default_cursor == NULL;
+        self->default_cursor = NULL;
     }	
 
     g_mozilla_connectivity_unset_global(self);
